<?xml version="1.0" encoding="utf-8"?>
<Rule
  Description="Razor Properties"
  DisplayName="Razor Properties"
  Name="RazorGeneral"
  PageTemplate="generic"
  xmlns="http://schemas.microsoft.com/build/2009/properties">
  <Rule.DataSource>
    <DataSource
      Persistence="ProjectFile"
      HasConfigurationCondition="True" />
  </Rule.DataSource>

  <Rule.Categories>
    <Category
      Name="General"
      DisplayName="General" />
  </Rule.Categories>

  <StringProperty
    Category="General"
    Description="Razor Language Version"
    DisplayName="Razor Language Version"
    Name="RazorLangVersion"
    ReadOnly="True"
    Visible="False" />

  <StringProperty
    Category="General"
    Description="Razor Configuration Name"
    DisplayName="Razor Configuration Name"
    Name="RazorDefaultConfiguration"
    ReadOnly="True"
    Visible="False" />

</Rule>
